==> playx_version_update-0.0.1.tar.gz: lib/src/core/model/result/playx_version_update_error.dart <==
const String _activityNotFoundErrorCode = 'ACTIVITY_NOT_FOUND';
const String _appUpdateMangerNotFoundErrorCode = 'APP_UPDATE_MANGER_NOT_FOUND';
const String _playxRequestCanceledErrorCode = 'PLAYX_REQUEST_CANCELLED';
const String _playxUpdateNotAvailableErrorCode = 'PLAYX_UPDATE_NOT_AVAILABLE';
const String _playxUpdateNotAllowedErrorCode = 'PLAYX_UPDATE_NOT_ALLOWED';
const String _playxUnknownUpdateTypeError = 'PLAYX_UNKNOWN_UPDATE_TYPE';
const String _playxInAppUpdateFailedErrorCode = 'PLAYX_IN_APP_UPDATE_FAILED';
const String defaultFailureErrorCode = 'DEFAULT_FAILURE_ERROR';

sealed class PlayxVersionUpdateError {
  String get message;

  String get errorCode;

  const PlayxVersionUpdateError();

  factory PlayxVersionUpdateError.fromInAppUpdateErrorCode(
      String errorCode, String errorMessage) {
    return switch (errorCode) {
      _activityNotFoundErrorCode => ActivityNotFoundError(),
      _appUpdateMangerNotFoundErrorCode => AppUpdateMangerNotFoundError(),
      _playxRequestCanceledErrorCode => PlayxRequestCanceledError(),
      _playxUpdateNotAvailableErrorCode => PlayxUpdateNotAvailableError(),
      _playxUpdateNotAllowedErrorCode => PlayxUpdateNotAllowedError(),
      _playxUnknownUpdateTypeError => PlayxUnknownUpdateTypeError(),
      _playxInAppUpdateFailedErrorCode => PlayxInAppUpdateFailedError(),
      defaultFailureErrorCode => DefaultFailureError(errorMsg: errorMessage),
      _ => DefaultFailureError(errorMsg: errorMessage)
    };
  }
}

class ActivityNotFoundError extends PlayxVersionUpdateError {
  @override
  String get message =>
      "Activity is not available. The app must be in Foreground.";

  @override
  String get errorCode => _activityNotFoundErrorCode;
}

class AppUpdateMangerNotFoundError extends PlayxVersionUpdateError {
  @override
  String get message => "App update manger is not available.";

  @override
  String get errorCode => _appUpdateMangerNotFoundErrorCode;
}

class PlayxRequestCanceledError extends PlayxVersionUpdateError {
  @override
  String get message => "Getting update info request was cancelled.";

  @override
  String get errorCode => _playxRequestCanceledErrorCode;
}

class PlayxUpdateNotAvailableError extends PlayxVersionUpdateError {
  @override
  String get message => "Update is not available.";

  @override
  String get errorCode => _playxUpdateNotAvailableErrorCode;
}

class PlayxUpdateNotAllowedError extends PlayxVersionUpdateError {
  @override
  String get message => "Update is not allowed.";

  @override
  String get errorCode => _playxUpdateNotAllowedErrorCode;
}

class PlayxUnknownUpdateTypeError extends PlayxVersionUpdateError {
  @override
  String get message => "Unknown update type.";

  @override
  String get errorCode => _playxUnknownUpdateTypeError;
}

class PlayxInAppUpdateFailedError extends PlayxVersionUpdateError {
  @override
  String get message => "In app update failed.";

  @override
  String get errorCode => _playxInAppUpdateFailedErrorCode;
}

class DefaultFailureError extends PlayxVersionUpdateError {
  final String? errorMsg;

  const DefaultFailureError({this.errorMsg});

  @override
  String get errorCode => defaultFailureErrorCode;

  @override
  String get message => errorMsg ?? 'unknown error';
}

//Version Check errors
class NotFoundError extends PlayxVersionUpdateError {
  const NotFoundError();

  @override
  String get message => "couldn't find the application";

  @override
  String get errorCode => 'NOT_FOUND_ERROR';
}

class SendTimeoutException extends PlayxVersionUpdateError {
  const SendTimeoutException();

  @override
  String get message => 'send timeout';

  @override
  String get errorCode => 'SEND_TIMEOUT_ERROR';
}

class NoInternetConnectionException extends PlayxVersionUpdateError {
  const NoInternetConnectionException();

  @override
  String get message => 'No Internet Connection';

  @override
  String get errorCode => 'NO_INTERNET_CONNECTION_ERROR';
}

class InternalServerErrorException extends PlayxVersionUpdateError {
  const InternalServerErrorException();

  @override
  String get message => 'Internal Server Error';

  @override
  String get errorCode => 'INTERNAL_SERVER_ERROR';
}

class ServiceUnavailableException extends PlayxVersionUpdateError {
  const ServiceUnavailableException();

  @override
  String get message => 'Service unavailable';

  @override
  String get errorCode => 'SERVICE_UNAVAILABLE_ERROR';
}

class RequestTimeoutException extends PlayxVersionUpdateError {
  const RequestTimeoutException();

  @override
  String get message => 'Request timeout';

  @override
  String get errorCode => 'REQUEST_TIMEOUT_ERROR';
}

class NotSupportedException extends PlayxVersionUpdateError {
  const NotSupportedException();

  @override
  String get message => 'not supported';

  @override
  String get errorCode => 'NOT_SUPPORTED_ERROR_CODE';
}

class PlayxVersionCantUpdateError extends PlayxVersionUpdateError {
  final String currentVersion;
  final String newVersion;
  const PlayxVersionCantUpdateError(
      {required this.currentVersion, required this.newVersion});

  @override
  String get message =>
      "Can't update version as the current version is $currentVersion and the new version is $newVersion";

  @override
  String get errorCode => 'PLAYX_VERSION_CANT_UPDATE_ERROR_CODE';
}

class VersionFormatException extends PlayxVersionUpdateError {
  const VersionFormatException();

  @override
  String get message => "couldn't format version";

  @override
  String get errorCode => 'VERSION_FORMAT_ERROR';
}

==> playx_version_update-0.0.2.tar.gz: lib/src/core/model/result/playx_version_update_error.dart <==
const String _activityNotFoundErrorCode = 'ACTIVITY_NOT_FOUND';
const String _appUpdateMangerNotFoundErrorCode = 'APP_UPDATE_MANGER_NOT_FOUND';
const String _playxInAppUpdateInfoRequestCanceledErrorCode =
    'PLAYX_REQUEST_CANCELLED';
const String _playxInAppUpdateCanceledErrorCode = 'PLAYX_UPDATE_CANCELLED';

const String _playxUpdateNotAvailableErrorCode = 'PLAYX_UPDATE_NOT_AVAILABLE';
const String _playxUpdateNotAllowedErrorCode = 'PLAYX_UPDATE_NOT_ALLOWED';
const String _playxUnknownUpdateTypeError = 'PLAYX_UNKNOWN_UPDATE_TYPE';
const String _playxInAppUpdateFailedErrorCode = 'PLAYX_IN_APP_UPDATE_FAILED';
const String defaultFailureErrorCode = 'DEFAULT_FAILURE_ERROR';

sealed class PlayxVersionUpdateError {
  String get message;

  String get errorCode;

  const PlayxVersionUpdateError();

  factory PlayxVersionUpdateError.fromInAppUpdateErrorCode(
      String errorCode, String errorMessage) {
    return switch (errorCode) {
      _activityNotFoundErrorCode => ActivityNotFoundError(),
      _appUpdateMangerNotFoundErrorCode => AppUpdateMangerNotFoundError(),
      _playxInAppUpdateInfoRequestCanceledErrorCode =>
        PlayxInAppUpdateInfoRequestCanceledError(),
      _playxInAppUpdateCanceledErrorCode => PlayxInAppUpdateCanceledError(),
      _playxUpdateNotAvailableErrorCode => PlayxUpdateNotAvailableError(),
      _playxUpdateNotAllowedErrorCode => PlayxUpdateNotAllowedError(),
      _playxUnknownUpdateTypeError => PlayxUnknownUpdateTypeError(),
      _playxInAppUpdateFailedErrorCode => PlayxInAppUpdateFailedError(),
      defaultFailureErrorCode => DefaultFailureError(errorMsg: errorMessage),
      _ => DefaultFailureError(errorMsg: errorMessage)
    };
  }
}

/// Error happens when the current activity is not available like when the app is in the background.
class ActivityNotFoundError extends PlayxVersionUpdateError {
  @override
  String get message =>
      "Activity is not available. The app must be in Foreground.";

  @override
  String get errorCode => _activityNotFoundErrorCode;
}

/// Error happens when the App update manger is not available.
class AppUpdateMangerNotFoundError extends PlayxVersionUpdateError {
  @override
  String get message => "App update manger is not available.";

  @override
  String get errorCode => _appUpdateMangerNotFoundErrorCode;
}

/// Error happens when the request to check if update is available is canceled .
class PlayxInAppUpdateInfoRequestCanceledError extends PlayxVersionUpdateError {
  @override
  String get message =>
      "In app update info request was cancelled when checking update availability.";

  @override
  String get errorCode => _playxInAppUpdateInfoRequestCanceledErrorCode;
}

/// Error happens when the in app update was canceled .
class PlayxInAppUpdateCanceledError extends PlayxVersionUpdateError {
  @override
  String get message => "In app update was cancelled.";

  @override
  String get errorCode => _playxInAppUpdateCanceledErrorCode;
}

/// Error happens when in app update is not available .
class PlayxUpdateNotAvailableError extends PlayxVersionUpdateError {
  @override
  String get message => "In app update is not available.";

  @override
  String get errorCode => _playxUpdateNotAvailableErrorCode;
}

/// Error happens when in app update is not allowed .
class PlayxUpdateNotAllowedError extends PlayxVersionUpdateError {
  @override
  String get message => "Update is not allowed.";

  @override
  String get errorCode => _playxUpdateNotAllowedErrorCode;
}

/// Error happens when in passing an unknown update type.
class PlayxUnknownUpdateTypeError extends PlayxVersionUpdateError {
  @override
  String get message => "Unknown update type.";

  @override
  String get errorCode => _playxUnknownUpdateTypeError;
}

/// Error happens when in app update was failed due to other error .
class PlayxInAppUpdateFailedError extends PlayxVersionUpdateError {
  @override
  String get message => "In app update failed.";

  @override
  String get errorCode => _playxInAppUpdateFailedErrorCode;
}

/// Default failure error.
class DefaultFailureError extends PlayxVersionUpdateError {
  final String? errorMsg;

  const DefaultFailureError({this.errorMsg});

  @override
  String get errorCode => defaultFailureErrorCode;

  @override
  String get message => errorMsg ?? 'unknown error';
}

//Version Check errors

/// Error happens when the package can't find the application on the store.
class NotFoundError extends PlayxVersionUpdateError {
  const NotFoundError();

  @override
  String get message => "couldn't find the application";

  @override
  String get errorCode => 'NOT_FOUND_ERROR';
}

/// Error happens when the version check network request was canceled.
class PlayxNetworkRequestCanceledError extends PlayxVersionUpdateError {
  @override
  String get message =>
      "Getting update info request from network was cancelled.";

  @override
  String get errorCode => 'PLAYX_NETWORK_REQUEST_CANCELLED_ERROR';
}

/// Error happens when the version check network request had timeout.
class SendTimeoutException extends PlayxVersionUpdateError {
  const SendTimeoutException();

  @override
  String get message => 'send timeout';

  @override
  String get errorCode => 'SEND_TIMEOUT_ERROR';
}

/// Error happens when there's no internet connection.
class NoInternetConnectionException extends PlayxVersionUpdateError {
  const NoInternetConnectionException();

  @override
  String get message => 'No Internet Connection';

  @override
  String get errorCode => 'NO_INTERNET_CONNECTION_ERROR';
}

/// Error happens when the version check network request received internal server error.
class InternalServerErrorException extends PlayxVersionUpdateError {
  const InternalServerErrorException();

  @override
  String get message => 'Internal Server Error';

  @override
  String get errorCode => 'INTERNAL_SERVER_ERROR';
}

/// Error happens when the version check network request received unavailable service error.
class ServiceUnavailableException extends PlayxVersionUpdateError {
  const ServiceUnavailableException();

  @override
  String get message => 'Service unavailable';

  @override
  String get errorCode => 'SERVICE_UNAVAILABLE_ERROR';
}

/// Error happens when the version check network request received request timeout error.
class RequestTimeoutException extends PlayxVersionUpdateError {
  const RequestTimeoutException();

  @override
  String get message => 'Request timeout';

  @override
  String get errorCode => 'REQUEST_TIMEOUT_ERROR';
}

/// Error happens when the version check has unsupported version.
class NotSupportedException extends PlayxVersionUpdateError {
  const NotSupportedException();

  @override
  String get message => 'not supported';

  @override
  String get errorCode => 'NOT_SUPPORTED_ERROR_CODE';
}

/// Error happens when the version check the app can't update because new version is below or the same as current one.
class PlayxVersionCantUpdateError extends PlayxVersionUpdateError {
  final String currentVersion;
  final String newVersion;
  const PlayxVersionCantUpdateError(
      {required this.currentVersion, required this.newVersion});

  @override
  String get message =>
      "Can't update version as the current version is $currentVersion and the new version is $newVersion";

  @override
  String get errorCode => 'PLAYX_VERSION_CANT_UPDATE_ERROR_CODE';
}

/// Error happens when the version was not formatted correctly.
class VersionFormatException extends PlayxVersionUpdateError {
  const VersionFormatException();

  @override
  String get message => "couldn't format version";

  @override
  String get errorCode => 'VERSION_FORMAT_ERROR';
}
